==============
Flask-Fundatio
==============

**Flask-Fundatio** is a `Flask`_ extension that provides integration with the
`Foundation`_ front-end framework.

.. _`Flask`: http://flask.pocoo.org/
.. _`Foundation`: http://foundation.zurb.com/

This extension bundles Foundation 4.2.3 with the default CSS, and the Foundicon
icon sets.

Usage
=====

The ``example/`` directory contains a simple example of a Flask application. It
shows how to use this extension to render a simple page template that extends a
base template.
